==> zio-aws-docdb_2.13-5.17.104.13-sources.jar: zio/aws/docdb/model/FailoverDbClusterRequest.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class FailoverDbClusterRequest(
    dbClusterIdentifier: Option[String] = None,
    targetDBInstanceIdentifier: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.FailoverDbClusterRequest = {
    import FailoverDbClusterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.FailoverDbClusterRequest
      .builder()
      .optionallyWith(
        dbClusterIdentifier.map(value => value: java.lang.String)
      )(_.dbClusterIdentifier)
      .optionallyWith(
        targetDBInstanceIdentifier.map(value => value: java.lang.String)
      )(_.targetDBInstanceIdentifier)
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.FailoverDbClusterRequest.ReadOnly =
    zio.aws.docdb.model.FailoverDbClusterRequest.wrap(buildAwsValue())
}
object FailoverDbClusterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.FailoverDbClusterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.FailoverDbClusterRequest =
      zio.aws.docdb.model.FailoverDbClusterRequest(
        dbClusterIdentifier.map(value => value),
        targetDBInstanceIdentifier.map(value => value)
      )
    def dbClusterIdentifier: Option[String]
    def targetDBInstanceIdentifier: Option[String]
    def getDbClusterIdentifier: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbClusterIdentifier", dbClusterIdentifier)
    def getTargetDBInstanceIdentifier: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "targetDBInstanceIdentifier",
        targetDBInstanceIdentifier
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.FailoverDbClusterRequest
  ) extends zio.aws.docdb.model.FailoverDbClusterRequest.ReadOnly {
    override val dbClusterIdentifier: Option[String] =
      scala.Option(impl.dbClusterIdentifier()).map(value => value: String)
    override val targetDBInstanceIdentifier: Option[String] = scala
      .Option(impl.targetDBInstanceIdentifier())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.FailoverDbClusterRequest
  ): zio.aws.docdb.model.FailoverDbClusterRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-docdb_2.13-5.20.7.3-sources.jar: zio/aws/docdb/model/FailoverDbClusterRequest.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class FailoverDbClusterRequest(
    dbClusterIdentifier: Optional[String] = Optional.Absent,
    targetDBInstanceIdentifier: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.FailoverDbClusterRequest = {
    import FailoverDbClusterRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.FailoverDbClusterRequest
      .builder()
      .optionallyWith(
        dbClusterIdentifier.map(value => value: java.lang.String)
      )(_.dbClusterIdentifier)
      .optionallyWith(
        targetDBInstanceIdentifier.map(value => value: java.lang.String)
      )(_.targetDBInstanceIdentifier)
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.FailoverDbClusterRequest.ReadOnly =
    zio.aws.docdb.model.FailoverDbClusterRequest.wrap(buildAwsValue())
}
object FailoverDbClusterRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.FailoverDbClusterRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.FailoverDbClusterRequest =
      zio.aws.docdb.model.FailoverDbClusterRequest(
        dbClusterIdentifier.map(value => value),
        targetDBInstanceIdentifier.map(value => value)
      )
    def dbClusterIdentifier: Optional[String]
    def targetDBInstanceIdentifier: Optional[String]
    def getDbClusterIdentifier: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbClusterIdentifier", dbClusterIdentifier)
    def getTargetDBInstanceIdentifier: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField(
        "targetDBInstanceIdentifier",
        targetDBInstanceIdentifier
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.FailoverDbClusterRequest
  ) extends zio.aws.docdb.model.FailoverDbClusterRequest.ReadOnly {
    override val dbClusterIdentifier: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.dbClusterIdentifier())
      .map(value => value: String)
    override val targetDBInstanceIdentifier: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.targetDBInstanceIdentifier())
        .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.FailoverDbClusterRequest
  ): zio.aws.docdb.model.FailoverDbClusterRequest.ReadOnly = new Wrapper(impl)
}
